.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.domainui.workflow
------------------------------

.. automodule:: reahl.domainui.workflow


InboxRegion
"""""""""""

.. autoclass:: InboxRegion
   :members:

TaskWidget
""""""""""

.. autoclass:: TaskWidget
   :members:
